@@ -1,5 +1,5 @@
 """
-SQLObject 0.14.1
+SQLObject 0.15.0
 ----------------
 
 :author: Ian Bicking <ianb@colorstudy.com>
@@ -461,8 +461,8 @@ class sqlmeta(object):
                 raise IndexError(
                     "Column with definition %r not found" % column)
         post_funcs = []
-        cls.send(events.DeleteColumnSignal, connection, column.name, column,
-                 post_funcs)
+        cls.send(events.DeleteColumnSignal, cls.soClass, connection,
+                 column.name, column, post_funcs)
         name = column.name
         del sqlmeta.columns[name]
         del sqlmeta.columnDefinitions[name]
@@ -1001,7 +1001,7 @@ class SQLObject(object):
         post_funcs = []
         self.sqlmeta.send(events.RowUpdatedSignal, self, post_funcs)
         for func in post_funcs:
-            func()
+            func(self)
 
     def expire(self):
         if self.sqlmeta.expired:
@@ -1058,7 +1058,7 @@ class SQLObject(object):
         post_funcs = []
         self.sqlmeta.send(events.RowUpdatedSignal, self, post_funcs)
         for func in post_funcs:
-            func()
+            func(self)
 
     def set(self, _suppress_set_sig=False, **kw):
         if not self.sqlmeta._creating and not getattr(self.sqlmeta, "row_update_sig_suppress", False) and not _suppress_set_sig:
@@ -1150,7 +1150,7 @@ class SQLObject(object):
         post_funcs = []
         self.sqlmeta.send(events.RowUpdatedSignal, self, post_funcs)
         for func in post_funcs:
-            func()
+            func(self)
 
     def _SO_selectInit(self, row):
         for col, colValue in zip(self.sqlmeta.columnList, row):
@@ -1207,7 +1207,7 @@ class SQLObject(object):
                 return
 
             post_funcs = []
-            self.sqlmeta.send(events.RowCreateSignal, kw, post_funcs)
+            self.sqlmeta.send(events.RowCreateSignal, self, kw, post_funcs)
 
             # Pass the connection object along if we were given one.
             if kw.has_key('connection'):
@@ -1303,7 +1303,7 @@ class SQLObject(object):
         post_funcs = []
         kw = dict([('class', self.__class__), ('id', id)])
         def _send_RowCreatedSignal():
-            self.sqlmeta.send(events.RowCreatedSignal, kw, post_funcs)
+            self.sqlmeta.send(events.RowCreatedSignal, self, kw, post_funcs)
             for func in post_funcs:
                 func(self)
         _postponed_local.postponed_calls.append(_send_RowCreatedSignal)
@@ -1584,12 +1584,12 @@ class SQLObject(object):
         self._connection.cache.expire(self.id, self.__class__)
 
         for func in post_funcs:
-            func()
+            func(self)
 
         post_funcs = []
         self.sqlmeta.send(events.RowDestroyedSignal, self, post_funcs)
         for func in post_funcs:
-            func()
+            func(self)
 
     def delete(cls, id, connection=None):
         obj = cls.get(id, connection=connection)
